@@ -13,7 +13,7 @@ test_emacs "(let ((notmuch-hello-sections
                                      \"Test\" '((\"inbox\" . \"tag:inbox\")))))))
            (notmuch-hello)
            (test-output))"
-test_expect_equal_file OUTPUT $EXPECTED/notmuch-hello-new-section
+test_expect_equal_file $EXPECTED/notmuch-hello-new-section OUTPUT
 
 test_begin_subtest "User-defined section with empty, hidden entry"
 test_emacs "(let ((notmuch-hello-sections
@@ -24,7 +24,7 @@ test_emacs "(let ((notmuch-hello-sections
                                      :hide-empty-searches t)))))
              (notmuch-hello)
              (test-output))"
-test_expect_equal_file OUTPUT $EXPECTED/notmuch-hello-section-with-empty
+test_expect_equal_file $EXPECTED/notmuch-hello-section-with-empty OUTPUT
 
 test_begin_subtest "User-defined section, unread tag filtered out"
 test_emacs "(let ((notmuch-hello-sections
@@ -33,7 +33,7 @@ test_emacs "(let ((notmuch-hello-sections
                                      :hide-tags '(\"unread\"))))))
              (notmuch-hello)
              (test-output))"
-test_expect_equal_file OUTPUT $EXPECTED/notmuch-hello-section-hidden-tag
+test_expect_equal_file $EXPECTED/notmuch-hello-section-hidden-tag OUTPUT
 
 test_begin_subtest "User-defined section, different query for counts"
 test_emacs "(let ((notmuch-hello-sections
@@ -42,21 +42,21 @@ test_emacs "(let ((notmuch-hello-sections
                                      :filter-count \"tag:signed\")))))
              (notmuch-hello)
              (test-output))"
-test_expect_equal_file OUTPUT $EXPECTED/notmuch-hello-section-counts
+test_expect_equal_file $EXPECTED/notmuch-hello-section-counts OUTPUT
 
 test_begin_subtest "Empty custom tags section"
 test_emacs "(let* ((widget (widget-create 'notmuch-hello-tags-section))
                    (notmuch-hello-sections (list (widget-value widget))))
              (notmuch-hello)
              (test-output))"
-test_expect_equal_file OUTPUT $EXPECTED/notmuch-hello-empty-custom-tags-section
+test_expect_equal_file $EXPECTED/notmuch-hello-empty-custom-tags-section OUTPUT
 
 test_begin_subtest "Empty custom queries section"
 test_emacs "(let* ((widget (widget-create 'notmuch-hello-query-section))
                    (notmuch-hello-sections (list (widget-value widget))))
              (notmuch-hello)
              (test-output))"
-test_expect_equal_file OUTPUT $EXPECTED/notmuch-hello-empty-custom-queries-section
+test_expect_equal_file $EXPECTED/notmuch-hello-empty-custom-queries-section OUTPUT
 
 test_begin_subtest "Column alignment for tag/queries with long names"
 tag=a-very-long-tag # length carefully calculated for 80 characters window width
@@ -64,6 +64,6 @@ notmuch tag +$tag '*'
 test_emacs '(notmuch-hello)
             (test-output)'
 notmuch tag -$tag '*'
-test_expect_equal_file OUTPUT $EXPECTED/notmuch-hello-long-names
+test_expect_equal_file $EXPECTED/notmuch-hello-long-names OUTPUT
 
 test_done
